@@ -30,11 +30,11 @@
 
 =head1 NAME
 
-Locale::Po4a::Dia - Convert uncompressed Dia diagrams from/to PO files
+Locale::Po4a::Dia - convert uncompressed Dia diagrams from/to PO files
 
 =head1 DESCRIPTION
 
-The po4a (po for anything) project goal is to ease translations (and more
+The po4a (PO for anything) project goal is to ease translations (and more
 interestingly, the maintenance of translations) using gettext tools on
 areas where they were not expected like documentation.
 
@@ -62,7 +62,7 @@ tag), not interesting for translation.
 
 =head1 SEE ALSO
 
-L<po4a(7)|po4a.7>, L<Locale::Po4a::TransTractor(3pm)>, L<Locale::Po4a::Xml(3pm)>.
+L<Locale::Po4a::TransTractor(3pm)>, L<Locale::Po4a::Xml(3pm)>, L<po4a(7)|po4a.7>
 
 =head1 AUTHORS
 
