@@ -33,11 +33,11 @@
 
 =head1 NAME
 
-Locale::Po4a::Sgml - Convert sgml documents from/to PO files
+Locale::Po4a::Sgml - convert SGML documents from/to PO files
 
 =head1 DESCRIPTION
 
-The po4a (po for anything) project goal is to ease translations (and more
+The po4a (PO for anything) project goal is to ease translations (and more
 interestingly, the maintenance of translations) using gettext tools on
 areas where they were not expected like documentation.
 
@@ -52,46 +52,46 @@ Also make sure that the DTD of the SGML files are installed in the system.
 
 =over 4
 
-=item debug
+=item B<debug>
 
 Space separated list of keywords indicating which part you want to debug. Possible values are: tag, generic, entities and refs.
 
-=item verbose
+=item B<verbose>
 
 Give more information about what's going on.
 
-=item translate
+=item B<translate>
 
-Space separated list of extra tags (beside the dtd provided ones) whose
+Space separated list of extra tags (beside the DTD provided ones) whose
 content should form an extra msgid.
 
-=item section
+=item B<section>
 
-Space separated list of extra tags (beside the dtd provided ones)
-containing other tags, some of them being of category 'translate'.
+Space separated list of extra tags (beside the DTD provided ones)
+containing other tags, some of them being of category B<translate>.
 
-=item indent
+=item B<indent>
 
 Space separated list of tags which increase the indentation level.
 
-=item verbatim
+=item B<verbatim>
 
 The layout within those tags should not be changed. The paragraph won't get
 wrapped, and no extra indentation space or new line will be added for
 cosmetic purpose.
 
-=item empty
+=item B<empty>
 
 Tags not needing to be closed.
 
-=item ignore
+=item B<ignore>
 
 Tags ignored and considered as plain char data by po4a. That is to say that
 they can be part of an msgid. For example, E<lt>bE<gt> is a good candidate
 for this category since putting it in the translate section would create
 msgids not being whole sentences, which is bad.
 
-=item attributes
+=item B<attributes>
 
 A space separated list of attributes that need to be translated. You can
 specify the attributes by their name (for example, "lang"), but you can also
@@ -103,25 +103,25 @@ The tag names are actually regular expressions so you can also write things
 like E<lt>aaa|bbbbE<gt>lang to only translate lang attributes that are in
 an E<lt>aaaE<gt> or a E<lt>bbbE<gt> tag.
 
-=item qualify
+=item B<qualify>
 
 A space separated list of attributes for which the translation must be
 qualified by the attribute name. Note that this setting automatically adds the
 given attribute into the 'attributes' list too.
 
-=item force
+=item B<force>
 
 Proceed even if the DTD is unknown or if nsgmls finds errors in the input
 file.
 
-=item include-all
+=item B<include-all>
 
 By default, msgids containing only one entity (like '&version;') are skipped
 for the translator comfort. Activating this option prevents this
 optimisation. It can be useful if the document contains a construction like
 "<title>&Aacute;</title>", even if I doubt such things to ever happen...
 
-=item ignore-inclusion
+=item B<ignore-inclusion>
 
 Space separated list of entities that won't be inlined.
 Use this option with caution: it may cause nsgmls (used internally) to add
@@ -138,10 +138,10 @@ same. But there are still some problems:
 
 =item *
 
-the error output of nsgmls is redirected to /dev/null, which is clearly
+The error output of nsgmls is redirected to /dev/null, which is clearly
 bad. I don't know how to avoid that.
 
-The problem is that I have to "protect" the conditional inclusions (ie, the
+The problem is that I have to "protect" the conditional inclusions (i.e. the
 C<E<lt>! [ %foo [> and C<]]E<gt>> stuff) from nsgmls. Otherwise
 nsgmls eats them, and I don't know how to restore them in the final
 document. To prevent that, I rewrite them to C<{PO4A-beg-foo}> and
@@ -155,8 +155,8 @@ prevent us from detecting that the document is badly formatted.
 
 =item *
 
-It does work only with the debiandoc and docbook dtd. Adding support for a
-new dtd should be very easy. The mechanism is the same for every dtd, you just
+It does work only with the DebianDoc and DocBook DTD. Adding support for a
+new DTD should be very easy. The mechanism is the same for every DTD, you just
 have to give a list of the existing tags and some of their characteristics.
 
 I agree, this needs some more documentation, but it is still considered as
@@ -164,31 +164,31 @@ beta, and I hate to document stuff which may/will change.
 
 =item *
 
-Warning, support for dtds is quite experimental. I did not read any
+Warning, support for DTDs is quite experimental. I did not read any
 reference manual to find the definition of every tag. I did add tag
 definition to the module 'till it works for some documents I found on the
 net. If your document use more tags than mine, it won't work. But as I said
 above, fixing that should be quite easy.
 
-I did test docbook against the SAG (System Administrator Guide) only, but
-this document is quite big, and should use most of the docbook
+I did test DocBook against the SAG (System Administrator Guide) only, but
+this document is quite big, and should use most of the DocBook
 specificities.
 
-For debiandoc, I tested some of the manuals from the DDP, but not all yet.
+For DebianDoc, I tested some of the manuals from the DDP, but not all yet.
 
 =item *
 
-In case of file inclusion, string reference of messages in po files (ie,
-lines like C<#: en/titletoc.sgml:9460>) will be wrong.
+In case of file inclusion, string reference of messages in PO files
+(i.e. lines like C<#: en/titletoc.sgml:9460>) will be wrong.
 
 This is because I preprocess the file to protect the conditional inclusion
-(ie, the C<E<lt>! [ %foo [> and C<]]E<gt>> stuff) and some entities (like
+(i.e. the C<E<lt>! [ %foo [> and C<]]E<gt>> stuff) and some entities (like
 &version;) from nsgmls because I want them verbatim to the generated
 document. For that, I make a temp copy of the input file and do all the
 changes I want to this before passing it to nsgmls for parsing.
 
 So that it works, I replace the entities asking for a file inclusion by the
-content of the given file (so that I can protect what needs to in subfile
+content of the given file (so that I can protect what needs to be in a subfile
 also). But nothing is done so far to correct the references (i.e., filename
 and line number) afterward. I'm not sure what the best thing to do is.
 
@@ -362,7 +362,7 @@ sub parse_file {
     my ($prolog);
 
     # Rewrite the file to:
-    #   - protect optional inclusion marker (ie, "<![ %str [" and "]]>")
+    #   - protect optional inclusion marker (i.e. "<![ %str [" and "]]>")
     #   - protect entities from expansion (ie "&release;")
     my $origfile="";
     my $i=0;
@@ -531,7 +531,7 @@ sub parse_file {
 	    $self->set_tags_kind();
 	} else {
 	    die wrap_mod("po4a::sgml", dgettext("po4a",
-		"DTD of this file is unknown. (supported: debiandoc, docbook). The prolog follows:")."\n$prolog");
+		"DTD of this file is unknown. (supported: DebianDoc, DocBook). The prolog follows:")."\n$prolog");
 	}
     }
 
