@@ -11,7 +11,7 @@ use warnings;
 
 use subs qw(makespace);
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION="0.41";
+$VERSION="0.42";
 @ISA = qw(DynaLoader);
 @EXPORT = qw(new process translate 
              read write readpo writepo
@@ -41,9 +41,9 @@ The po4a (PO for anything) project goal is to ease translations (and more
 interestingly, the maintenance of translations) using gettext tools on
 areas where they were not expected like documentation.
 
-This class is the ancestor of every po4a parsers used to parse a document to
-search translatable strings, extract them to a PO file and replace them by
-their translation in the output document. 
+This class is the ancestor of every po4a parser used to parse a document, to
+search translatable strings, to extract them to a PO file and to replace them by
+their translation in the output document.
 
 More formally, it takes the following arguments as input:
 
@@ -51,7 +51,7 @@ More formally, it takes the following arguments as input:
 
 =item -
 
-a document to translate ;
+a document to translate;
 
 =item -
 
@@ -66,7 +66,7 @@ As output, it produces:
 =item -
 
 another PO file, resulting of the extraction of translatable strings from
-the input document ;
+the input document;
 
 =item -
 
@@ -94,7 +94,7 @@ Here is a graphical representation of this:
 This is where all the work takes place: the parsing of input documents, the
 generation of output, and the extraction of the translatable strings. This
 is pretty simple using the provided functions presented in the section
-B<INTERNAL FUNCTIONS> below. See also the B<SYNOPSIS>, which present an
+B<INTERNAL FUNCTIONS> below. See also the B<SYNOPSIS>, which presents an
 example.
 
 This function is called by the process() function below, but if you choose
@@ -481,7 +481,7 @@ sub write {
 
 =item readpo($)
 
-Add the content of a file (which name is passed in argument) to the
+Add the content of a file (which name is passed as argument) to the
 existing input PO. The old content is not discarded.
 
 =item writepo($)
@@ -662,7 +662,7 @@ sub addendum {
 	my @newres=();
 
 	do {
-	    # make sure it doesnt whine on empty document
+	    # make sure it doesn't whine on empty document
 	    my $line = scalar @{$self->{TT}{doc_out}} ? shift @{$self->{TT}{doc_out}} : "";
 	    push @newres,$line;
 	    my $outline=mychomp($line);
@@ -768,12 +768,12 @@ A string to translate
 
 =item -
 
-The reference of this string (ie, position in inputfile)
+The reference of this string (i.e. position in inputfile)
 
 =item -
 
-The type of this string (ie, the textual description of its structural role
-; used in Locale::Po4a::Po::gettextization() ; see also L<po4a(7)|po4a.7>,
+The type of this string (i.e. the textual description of its structural role;
+used in Locale::Po4a::Po::gettextization(); see also L<po4a(7)|po4a.7>,
 section B<Gettextization: how does it work?>)
 
 =back
